// Copyright (c) 2020-2023 by the Zeek Project. See LICENSE for details.

#include <hilti/ast/meta.h>

using namespace hilti;

std::unordered_set<Meta> Meta::_cache;
